#!/bin/bash

#  slackbuild script for icewm
# Author: Mark Tucker
# Created: Jul 29, 2004
# Changes:
#        Jul 27, 2004 - initial creation
#        Jul 31, 2004 - cleaned up some checks and enabled i18/nls
#        Aug 09, 2004 - changed prefix to /usr/X11R6
#
#----------------------------------------------------------------------
umask 0022
#----------------------------------------
# Package variables
#----------------------------------------
srcdir=`pwd`/SRC
source="icewm-1.2.16.tar.gz"
pkgname="icewm"
pkgver="1.2.16"
release="3mht"
package="$pkgname-$pkgver-i486-$release.tgz"
echo Package: $package

#----------------------------------------
# setup path variables
#----------------------------------------
# where the source archive is located
thisfile=`pwd`/`basename $0`
# get working directory
workdir=`dirname $0`
if [ "$workdir" == "." ]; then
    workdir=`pwd`/$pkgname
    if [ ! -d $workdir ]; then
	echo Creating working directory $workdir ...
	mkdir -p $workdir
    fi
    echo Working directory is $workdir
    cd $workdir
    echo Changed directory to  `pwd`
fi
builddir=$workdir/$pkgname-$pkgver


# unpack the source
echo Unpacking the source...
tar -xzf $srcdir/$source

#----------------------------------------
# setup the build environment
#----------------------------------------
export CFLAGS="-O2 -march=i486 -mcpu=i686"
export CPPFLAGS="-O2 -march=i486 -mcpu=i686"
export CXXFLAGS=$CPPFLAGS


# change to build directory
cd $builddir

#--------------------------------------------------
#configure options:
#--------------------------------------------------
echo Running configure....
./configure --prefix=/usr/X11R6 \
    --sysconfdir=/etc \
    --datadir=/usr/share \
    --localstatedir=/var \
    --enable-wm-session \
    --enable-menus-gnome2 \
    --enable-antialiasing \
    --with-kdedatadir=/opt/kde/share \
    --enable-guievents \
    > $workdir/config.output 2>&1

# check config exit status
if [ $? -ne 0 ]; then
    echo There was a problem with the build process.
    echo check the contents of $workdir/config.output
    echo Exiting...
    exit
fi

#--------------------------------------------------
# build 
#--------------------------------------------------
echo Running make ...
make  > $workdir/make.output 2>&1

# check exit status of make process..
if [ $? -ne 0 ]; then
    echo There was a problem with the build process.
    echo check the contents of $workdir/make.output
    echo Exiting...
    exit
fi



# Set target directory
target=$workdir/target
if [ ! -d $target ]; then
    mkdir $target
fi

#--------------------------------------------------
# install
#--------------------------------------------------
echo Installing to $target ...
make install DESTDIR=$target > $workdir/install.output 2>&1


echo finishing install....
cd $target

# create install dir
mkdir $target/install

# copy slack-desc file to install
cp $workdir/slack-desc $target/install/

#----------------------------------------
# create slack-desc file to install
#----------------------------------------
cat > $target/install/slack-desc << END
     |-----handy-ruler------------------------------------------------------|
icewm: IceWM version $pkgver
icewm:
icewm: IceWM is a small, fast and familiar window manager for the X11
icewm: window system.
icewm:
icewm: http://www.icewm.org
icewm:
icewm:
icewm:
icewm:
icewm: Packaged for Slackware 10 by Mark Tucker

END

#----------------------------------------
# create documentation directory
#----------------------------------------
mkdir -p $target/usr/doc/$pkgname-$pkgver
cp $builddir/[A-Z]* $target/usr/doc/$pkgname-$pkgver/
cp $thisfile $target/usr/doc/$pkgname-$pkgver/SlackPkg.sh
# copy over $builddir/doc dir to $target/usr/doc/$pkgname-$pkgver/
cp -r $workdir/$pkgname-$pkgver/doc/*.html $target/usr/doc/$pkgname-$pkgver/
chmod a+r $target/usr/doc/$pkgname-$pkgver/*

# Create symlink for help files
#ln -s /usr/doc $target/usr/X11R6/share/doc

#----------------------------------------
# copy over xinit.icewm 
#----------------------------------------
mkdir -p $target/etc/X11/xinit
cat > $target/etc/X11/xinit/xinitrc.icewm <<EOF
#!/bin/sh
# \$XConsortium: xinitrc.cpp,v 1.4 91/08/22 11:41:34 rws Exp \$

userresources=\$HOME/.Xresources
usermodmap=\$HOME/.Xmodmap
sysresources=/usr/X11R6/lib/X11/xinit/.Xresources
sysmodmap=/usr/X11R6/lib/X11/xinit/.Xmodmap

# merge in defaults and keymaps

if [ -f \$sysresources ]; then
    xrdb -merge \$sysresources
fi

if [ -f \$sysmodmap ]; then
    xmodmap \$sysmodmap
fi

if [ -f \$userresources ]; then
    xrdb -merge \$userresources
fi

if [ -f \$usermodmap ]; then
    xmodmap \$usermodmap
fi

# start xscreensaver if it is available
if [ -x /usr/X11R6/bin/xscreensaver ]; then
    /usr/X11R6/bin/xscreensaver -no-splash &
fi

# start up gkrellm if it is available.
if [ -x /usr/bin/gkrellm ]; then
    /usr/bin/gkrellm &
fi

# Start the window manager:
exec /usr/X11R6/bin/icewm-session
#

EOF
chmod a+rx $target/etc/X11/xinit/xinitrc.icewm 


#----------------------------------------
# fix group on bin directories.
#----------------------------------------
for i in bin sbin usr/sbin usr/bin usr/X11R6/bin
do
  if [ -d $target/$i ]; then
      echo Changing group on $target/$i
      chgrp -R bin $target/$i
  fi
done

#----------------------------------------
# check for uncompressed man pages
#----------------------------------------
for i in usr/man opt/man usr/share/man usr/X11R6/man
do
  if [ -d $target/$i ]; then
      find $target/$i -name \*.[0-9] -exec gzip {} \;
  fi
done



#----------------------------------------
# makepkg
#----------------------------------------
echo Creating package...
makepkg  -c n -l y $workdir/$package

echo DONE

